@@ -21,11 +21,13 @@ TEXT_HEIGHT = 21
 TEXT_WIDTH = 12
 
 
-def _doRichRender(ansiText: str, wide: bool = True) -> Console:
-	console = Console(width=89 if wide else 49, record=True, file=StringIO())
+def _doRichRender(ansiText: str, wide: bool = True, width: int = 49) -> Console:
+	dynamicWidth = round(width * 1.82) if wide else width
+
+	console = Console(width=dynamicWidth, record=True, file=StringIO())
 	richText = text.Text.from_ansi(ansiText)
 	console.print(richText)
-	console.height = len(richText.wrap(console, width=89 if wide else 49))
+	console.height = len(richText.wrap(console, width=round(width * 1.82) if wide else width))
 	return console
 
 
@@ -62,7 +64,9 @@ def _hexToRGB(colourCode: str) -> tuple[int, int, int]:
 	return tuple(int(colourCode[i : i + 2], base=16) for i in (0, 2, 4))
 
 
-def ansiToSVG(ansiText: str, fileName: str, theme: str | None = None, wide: bool = True):
+def ansiToSVG(
+	ansiText: str, fileName: str, theme: str | None = None, wide: bool = True, width: int = 49
+):
 	"""Convert an ANSI stream to SVG.
 
 	Args:
@@ -70,18 +74,17 @@ def ansiToSVG(ansiText: str, fileName: str, theme: str | None = None, wide: bool
 		fileName (str): file path to SVG to write
 		theme (str, optional): file path to base24 theme to use. Defaults to "onedark.yml".
 		wide (bool, optional): use a 'wide' terminal 89 vs 49 chars
+		width (int, optional): set the width for the image
 	"""
-	console = _doRichRender(ansiText, wide)
+	console = _doRichRender(ansiText, wide, width)
 	console.save_svg(
-		fileName, title="AnsiToImg (courtesy of Rich)", theme=_doRichTerminalTheme(theme)
+		fileName, theme=_doRichTerminalTheme(theme), title="AnsiToImg (courtesy of Rich)"
 	)
 
 
-def ansiToRender(ansiText: str, fileName: str, theme: str | None = None, wide: bool = True):
-	return ansiToSVGRender(ansiText, fileName, theme, wide)
-
-
-def ansiToSVGRender(ansiText: str, fileName: str, theme: str | None = None, wide: bool = True):
+def ansiToRender(
+	ansiText: str, fileName: str, theme: str | None = None, wide: bool = True, width: int = 49
+):
 	"""Convert an ANSI stream to a Render image using pyppeteer to take a
 	screenshot of a generated SVG (hacky but we can get coloured emoji now)
 
@@ -90,10 +93,27 @@ def ansiToSVGRender(ansiText: str, fileName: str, theme: str | None = None, wide
 		fileName (str): image file path
 		theme (str, optional): file path to base24 theme to use. Defaults to "onedark.yml".
 		wide (bool, optional): use a 'wide' terminal 89 vs 49 chars
+		width (int, optional): set the width for the image
 	"""
-	console = _doRichRender(ansiText, wide)
+	return ansiToSVGRender(ansiText, fileName, theme, wide, width)
+
+
+def ansiToSVGRender(
+	ansiText: str, fileName: str, theme: str | None = None, wide: bool = True, width: int = 49
+):
+	"""Convert an ANSI stream to a Render image using pyppeteer to take a
+	screenshot of a generated SVG (hacky but we can get coloured emoji now)
+
+	Args:
+		ansiText (str): ANSI text to convert
+		fileName (str): image file path
+		theme (str, optional): file path to base24 theme to use. Defaults to "onedark.yml".
+		wide (bool, optional): use a 'wide' terminal 89 vs 49 chars
+		width (int, optional): set the width for the image
+	"""
+	console = _doRichRender(ansiText, wide, width)
 	tempFileName = f"{THISDIR}/temp.svg"
-	ansiToSVG(ansiText, tempFileName, theme, wide)
+	ansiToSVG(ansiText, tempFileName, theme, wide, width)
 	match = re.search(
 		r'^<svg.*?viewBox="[\d.]+ [\d.]+ ([\d.]+) ([\d.]+)',
 		Path(tempFileName).read_text(encoding="utf-8"),
@@ -118,7 +138,9 @@ async def _doGrabWebpage(url: str, resolution: tuple[int, int], fileName: str):
 	await browser.close()
 
 
-def ansiToHTML(ansiText: str, fileName: str, theme: str | None = None, wide: bool = True):
+def ansiToHTML(
+	ansiText: str, fileName: str, theme: str | None = None, wide: bool = True, width: int = 49
+):
 	"""Convert an ANSI stream to a html file.
 
 	Args:
@@ -126,12 +148,15 @@ def ansiToHTML(ansiText: str, fileName: str, theme: str | None = None, wide: boo
 		fileName (str): image file path
 		theme (str, optional): file path to base24 theme to use. Defaults to "onedark.yml".
 		wide (bool, optional): use a 'wide' terminal 89 vs 49 chars
+		width (int, optional): set the width for the image
 	"""
-	console = _doRichRender(ansiText, wide)
+	console = _doRichRender(ansiText, wide, width)
 	console.save_html(fileName, theme=_doRichTerminalTheme(theme))
 
 
-def ansiToHTMLRender(ansiText: str, fileName: str, theme: str | None = None, wide: bool = True):
+def ansiToHTMLRender(
+	ansiText: str, fileName: str, theme: str | None = None, wide: bool = True, width: int = 49
+):
 	"""Convert an ANSI stream to a Render image using pyppeteer to take a
 	screenshot of a generated html (hacky but we can output more like that
 	of a terminal now)
@@ -141,9 +166,10 @@ def ansiToHTMLRender(ansiText: str, fileName: str, theme: str | None = None, wid
 		fileName (str): image file path
 		theme (str, optional): file path to base24 theme to use. Defaults to "onedark.yml".
 		wide (bool, optional): use a 'wide' terminal 89 vs 49 chars
+		width (int, optional): set the width for the image
 	"""
-	console = _doRichRender(ansiText, wide)
-	ansiToHTML(ansiText, f"{THISDIR}/temp.html", theme, wide)
+	console = _doRichRender(ansiText, wide, width)
+	ansiToHTML(ansiText, f"{THISDIR}/temp.html", theme, wide, width)
 	size = (console.width * TEXT_WIDTH, (console.height + 1) * TEXT_HEIGHT)
 	asyncio.run(_doGrabWebpage(f"file:///{THISDIR}/temp.html", size, fileName))
 	try:
